ConvertPEDDataThis function converts Plink PED format files (PED/MAP) along with location files to the input required for OriGen.ConvertUnknownPEDDataThis function converts Plink PED format files (PED/MAP) along with location files to the input required for OriGen. This differs from ConvertPEDData by its additional PED formatted input which contains the genotype information for unknown individuals.ConvertMicrosatDataThis function converts Microsatellite data files into a format appropriate for analysis.FitOriGenModelFits the OriGen model for SNPs and returns the allele frequency surfaces. These surfaces can be plotted with the functionPlotAlleleFrequencySurface.FitMultinomialModelFits the OriGen model for microsatellites and returns the allele frequency surfaces. These surfaces can be plotted with the functionPlotAlleleFrequencySurface.FitOriGenModelFindUnknownsFits the OriGen model for SNPs and places individuals of unknown origin onto the map. This returns probability heat maps for each unknown individual. These heat maps can be plotted withPlotUnknownHeatMap. For microsatellite analysis seeFitMultinomialModelFindUnknowns.FitMultinomialModelFindUnknownsFits the OriGen model for microsatellites and places individuals of unknown origin onto the map. This returns probability heat maps for each unknown individual. These heat maps can be plotted withPlotUnknownHeatMap. For SNP analysis seeFitOriGenModelFindUnknowns.FitAdmixedModelFindUnknownsFits the OriGen model for SNPs and places unknown individuals who may be admixed onto the map. Instead of returning a probability heat map for each individual, this returns admixture fractions at each location. Note that many locations are 0. This can be plotted with the functionPlotAdmixedSurface.RankSNPsLRTThis function takes a PED file along with a location file and outputs the likelihood ratio ranking of each SNP along with the LRT statistic and Rosenberg's informativeness for assignment.PlotAlleleFrequencySurfacePlots a specified allele frequency surface from the output ofFitOriGenModelorFitMultinomialModel. Note that all alleles can be plotted by setting AlleleNumber=0.PlotUnknownHeatMapPlots a specified unknown individuals heat map from the output ofFitOriGenModelFindUnknownsorFitMultinomialModelFindUnknowns.PlotAdmixedSurfacePlots the admixture fractions of a specified individual from the output ofFitAdmixedModelFindUnknowns.